@@ -12,11 +12,11 @@ from simfin.names import *
 def prep_dataframe(file):
     pd.set_option('display.float_format', lambda x: '%.2f' % x)
     statement = pd.read_csv(file)
-    statement.Breakdown = statement.Breakdown.str.replace(' ', '_')
-    statement.Breakdown = statement.Breakdown.str.replace(',', '')
-    statement.Breakdown = statement.Breakdown.str.replace('&', '')
-    statement['Breakdown'] = statement['Breakdown'].str.lower()
-    statement = statement.set_index('Breakdown')
+    statement.iloc[:, 0] = statement.iloc[:, 0].str.replace(' ', '_')
+    statement.iloc[:, 0] = statement.iloc[:, 0].str.replace(',', '')
+    statement.iloc[:, 0] = statement.iloc[:, 0].str.replace('&', '')
+    statement.iloc[:, 0] = statement.iloc[:, 0].str.lower()
+    statement = statement.set_index(statement.columns[0])
     statement=statement.abs()
     return statement
 
@@ -29,75 +29,90 @@ def prep_json(file):
 
 #period = annual, quarterly
 #country= us
-def pull_finData(period,country):
+def prepare_finData(country):
     sf.set_api_key('free')
     sf.set_data_dir('~/simfin_data/')
     df_companies = sf.load_companies(market=country)
     df_industries = sf.load_industries()
-    df_income = sf.load_income(variant=period, market=country)
-    df_balance = sf.load_balance(variant=period, market=country)
-    df_cashflow = sf.load_cashflow(variant=period, market=country)
-    return df_companies, df_industries, df_income, df_balance, df_cashflow
+    
+def get_annual_finData_income(country):
+    prepare_finData(country)
+    df_income = sf.load_income(variant='annual', market=country)
+    df_income.columns = df_income.columns.str.replace(' ', '_')
+    return df_income
+
+def get_annual_finData_balance(country):
+    prepare_finData(country)
+    df_balance = sf.load_balance(variant='annual', market=country)
+    df_balance.columns = df_balance.columns.str.replace(' ', '_')
+    return df_balance
+
+def get_annual_finData_cashflow(country):
+    prepare_finData(country)
+    df_cashflow = sf.load_cashflow(variant='annual', market=country)
+    df_cashflow.columns = df_cashflow.columns.str.replace(' ', '_')
+    return df_cashflow
+
+def get_annual_finData_by_symbol(category,symbol,country):
+    try:
+        if category == "income":
+            df = get_annual_finData_income(country)
+        if category == "balancesheet":
+            df = get_annual_finData_balance(country)
+        if category == "cashflow":
+            df = get_annual_finData_cashflow(country)
+        df = df.loc[symbol].transpose()
+        df = df.rename(index={'Fiscal_Year': 'Breakdown'})
+        df.columns = df.loc['Breakdown']
+        df = df.drop(['SimFinId', 'Currency', 'Breakdown', 'Fiscal_Period', 'Publish_Date', 'Restated_Date']) 
+        return df
+    except UnboundLocalError:
+        print('Not a valid category')
+    except KeyError:
+        print('Not a valid symbol')
 
 def printStatement(file):
     statement = prep_dataframe(file)
     print(statement)
 
-def lineplot(file,category):
-    statement = prep_dataframe(file)
-
-    plotData = statement.T
+def lineplot(dataframe,category):
+    plotData = dataframe.T
     plotData = plotData.reset_index()
-    plotData['index']= pd.to_datetime(plotData['index']) 
-    plotData = plotData.sort_values(by='index')
-    plotData = plotData[['index',category]]
+    #plotData.columns[0]= pd.to_datetime(plotData.columns[0]) 
+    plotData = plotData.sort_values(plotData.columns[0])
+    plotData = plotData[[plotData.columns[0],category]]
+    plotData[category] = plotData[category].astype(float)
 
     plt.figure(figsize=(20,9))
-    sns.lineplot(data=plotData, x='index',y=category)
+    sns.lineplot(data=plotData, x=plotData.columns[0],y=category)
 
-def multiLineplot(file,title):
-    statement = prep_dataframe(file)
+# def multiLineplot(dataframe,title):
+#     statement = dataframe
 
-    plotData = statement.T
-    plotData = plotData.reset_index()
-    plotData['index']= pd.to_datetime(plotData['index'])
-    plotData = plotData.sort_values(by='index')
+#     plotData = statement.T
+#     plotData = plotData.reset_index()
+#     #plotData.iloc[:, 1]= pd.to_datetime(plotData.iloc[:, 1])
+#     plotData = plotData.sort_values(plotData.columns[0])
 
-    columnsList = list(plotData.columns.values)
-    graphRowCount=math.ceil(len(plotData.columns)/3)
-    fig = plt.figure(figsize=(30,45))
-    fig.suptitle(title, fontsize=30)
+#     columnsList = list(plotData.columns.values)
+#     graphRowCount=math.ceil(len(plotData.columns)/3)
+#     fig = plt.figure(figsize=(30,45))
+#     fig.suptitle(title, fontsize=30)
 
-    for x in range(1, len(columnsList)):
-        plotNumber = 'ax'+str(x)
-        colname = plotData.columns[x]
+#     for x in range(1, len(columnsList)):
+#         plotNumber = 'ax'+str(x)
+#         colname = plotData.columns[x]
 
-        plotNumber = fig.add_subplot(graphRowCount,3,x)
-        plotNumber.set_title(colname)
-        plotNumber.plot(plotData['index'],
-             plotData[colname])
-        plt.xticks(rotation=45)
+#         plotNumber = fig.add_subplot(graphRowCount,3,x)
+#         plotNumber.set_title(colname)
+#         plotNumber.plot(plotData.iloc[:, 1],
+#              plotData[colname])
+#         plt.xticks(rotation=45)
 
-    plt.show()
+#     plt.show()
 
 def calculateMetrics(balanceSheet,incomeStatement):
 
-    balanceSheet = pd.read_csv(balanceSheet)
-    incomeStatement = pd.read_csv(incomeStatement)
-
-    balanceSheet.Breakdown = balanceSheet.Breakdown.str.replace(' ', '_')
-    balanceSheet.Breakdown = balanceSheet.Breakdown.str.replace(',', '')
-    balanceSheet.Breakdown = balanceSheet.Breakdown.str.replace('&', '')
-    incomeStatement.Breakdown = incomeStatement.Breakdown.str.replace(' ', '_')
-    incomeStatement.Breakdown = incomeStatement.Breakdown.str.replace(',', '')
-    incomeStatement.Breakdown = incomeStatement.Breakdown.str.replace('&', '')
-    balanceSheet['Breakdown'] = balanceSheet['Breakdown'].str.lower()
-    incomeStatement['Breakdown'] = incomeStatement['Breakdown'].str.lower()
-    balanceSheet = balanceSheet.set_index('Breakdown')
-    incomeStatement = incomeStatement.set_index('Breakdown')
-    balanceSheet=balanceSheet.abs()
-    incomeStatement=incomeStatement.abs()
-
     frames = [balanceSheet, incomeStatement]
     Ratio = pd.DataFrame()
     dataframeForRatio = pd.concat(frames)
@@ -132,8 +147,8 @@ def calculateMetrics(balanceSheet,incomeStatement):
     Ratio = Ratio.round(4)
     print(Ratio)
     
-def bulletChart(file,item):
-    statement = prep_dataframe(file)
+def bulletChart(dataframe,item):
+    statement = dataframe
     
     data = statement.T
     data = data.reset_index()
@@ -154,8 +169,8 @@ def bulletChart(file,item):
     
     fig.show()
 
-def horizontalAnalysisLastTwo(file):
-    statement = prep_dataframe(file)
+def horizontalAnalysisLastTwo(dataframe):
+    statement = dataframe
     statement = statement.reindex(sorted(statement.columns), axis=1)
     statement_lastPeriods = statement[statement.columns[-2:]]
     statement_lastPeriods_lastColName = statement[statement_lastPeriods.columns[-1:]].columns.values[0]
